static

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Static

type Static struct {
	// contains filtered or unexported fields
}

Static reads the configuration for continuous task management from the yaml file and keeps it in memory.

func NewStatic

func NewStatic(path string) (*Static, error)

NewStatic makes new instance of Static flow provider.

func (*Static) ListSubscribedJobs

func (s *Static) ListSubscribedJobs(_ context.Context, triggerName string) ([]store.Job, error)

ListSubscribedJobs returns the jobs attached to the trigger by the name of the trigger.

func (*Static) ListTrackers

func (s *Static) ListTrackers(_ context.Context) ([]store.Tracker, error)

ListTrackers returns the list of registered trackers with their configurations.

func (*Static) ListTriggers

func (s *Static) ListTriggers(_ context.Context) ([]store.Trigger, error)

ListTriggers returns the list of registered triggers with their variables.

Jump to