Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger interface {
Printf(format string, v ...interface{})
}
Logger is a logger interface.
type Request ¶
type Request struct {
// TaskID in the target plugin, might be empty if the request is for creation
TaskID string `json:"task_id"`
Vars Vars `json:"vars"`
}
Request describes a request to tracker's action.
type Response ¶
type Response struct {
Task Task `json:"task"` // contains the update of the created/updated task in tracker
}
Response describes possible return values of the tracker's action.
type SubscribeReq ¶
SubscribeReq describes parameters of the subscription for task updates.
type SubscribeResp ¶
type SubscribeResp struct {
TrackerRef string `json:"tracker_ref"`
}
SubscribeResp describes the response of the subscription request.
type SubscriptionSupporter ¶
type SubscriptionSupporter interface {
Subscribe(req SubscribeReq, resp *SubscribeResp) error
Unsubscribe(req UnsubscribeReq, _ *struct{}) error
}
SubscriptionSupporter provides methods to subscribe to events. If plugin needs to support subscriptions, it should implement this interface.
type Task ¶ added in v0.2.0
type Task struct {
ID string `json:"id"`
URL string `json:"url"`
Title string `json:"title"`
Body string `json:"body"`
Fields map[string]string `json:"fields"`
}
Task describes an updated task representation in dastracker.
type UnsubscribeReq ¶
type UnsubscribeReq struct {
TrackerRef string `json:"tracker_ref"`
}
UnsubscribeReq describes parameters of the unsubscription from task updates.
type Vars ¶
Vars is an alias for a map with variable values.
func (Vars) Equal ¶
Equal returns true if two sets of variables represent the same one. Note: two sets of variables with different Evaluated state are considered to be equal, so the Evaluated state, in case if important, must be checked separately.