Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Static ¶
type Static struct {
// contains filtered or unexported fields
}
Static reads the configuration for continuous task management from the yaml file and keeps it in memory.
func (*Static) ListSubscribedJobs ¶
ListSubscribedJobs returns the jobs attached to the trigger by the name of the trigger.
func (*Static) ListTrackers ¶
ListTrackers returns the list of registered trackers with their configurations.
Click to show internal directories.
Click to hide internal directories.